.. ORMM documentation master file, created by
   sphinx-quickstart on Wed Jul 29 11:10:51 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

User Guide
================================
.. include:: ../../README.rst
   :start-line: 4

.. Table of contents - what tells sphinx hierarchy between files in document

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   problems/resource_allocation

.. toctree::
   :maxdepth: 2
   :caption: API Ref:

   api/modules
.. Indices and tables
  ==================
  * :ref:`genindex`
  * :ref:`modindex`
  * :ref:`search`
